---
title: <span class="badge object-type-scalar"></span> Pounds
---
# <span class="badge object-type-scalar"></span> Pounds

Currency: Pounds (£)

## Definition

```python
# Currency: Pounds (£)
Pounds: typing.Literal["currencyGBP"] = "currencyGBP"
```
